Please copy this file to your apache2 config folder.

    cp {{ abspath }} /etc/apache2/{{outfile}}

Then you can add this line to your site conf files (in /etc/apache2/sites-available)

    Include /etc/apache2/{{outfile}}
